@@ -5,6 +5,8 @@ from .utils import update_file
 from .utils import download_file
 from .utils import delete_file
 from .utils import get_file_list
+from .utils import get_file_path
+from .utils import decrypt_github_file
 from .watcher import Watcher
 from .shioaji_wrapper import ShioajiWrapper
 from .aes_crypt import AESCrypt
